==> kafka-3.7.2-src.tgz: kafka-3.7.2-src/connect/runtime/src/main/java/org/apache/kafka/connect/runtime/isolation/ClassLoaderFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.connect.runtime.isolation;

import java.net.URL;
import java.security.AccessController;
import java.security.PrivilegedAction;

/**
 * Factory for {@link DelegatingClassLoader} and {@link PluginClassLoader} instances.
 * Used for mocking classloader initialization in tests.
 */
public class ClassLoaderFactory implements PluginClassLoaderFactory {

    public DelegatingClassLoader newDelegatingClassLoader(ClassLoader parent) {
        return AccessController.doPrivileged(
                (PrivilegedAction<DelegatingClassLoader>) () -> new DelegatingClassLoader(parent)
        );
    }

    public PluginClassLoader newPluginClassLoader(URL pluginLocation, URL[] urls, ClassLoader parent) {
        return AccessController.doPrivileged(
                (PrivilegedAction<PluginClassLoader>) () -> new PluginClassLoader(pluginLocation, urls, parent)
        );
    }

}

==> kafka-4.2.0-src.tgz: kafka-4.2.0-src/connect/runtime/src/main/java/org/apache/kafka/connect/runtime/isolation/ClassLoaderFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.connect.runtime.isolation;

import org.apache.kafka.common.internals.SecurityManagerCompatibility;

import java.net.URL;

/**
 * Factory for {@link DelegatingClassLoader} and {@link PluginClassLoader} instances.
 * Used for mocking classloader initialization in tests.
 */
public class ClassLoaderFactory implements PluginClassLoaderFactory {

    public DelegatingClassLoader newDelegatingClassLoader(ClassLoader parent) {
        return SecurityManagerCompatibility.get().doPrivileged(
                () -> new DelegatingClassLoader(parent)
        );
    }

    public PluginClassLoader newPluginClassLoader(URL pluginLocation, URL[] urls, ClassLoader parent) {
        return SecurityManagerCompatibility.get().doPrivileged(
                () -> new PluginClassLoader(pluginLocation, urls, parent)
        );
    }

}
